Documentation
¶
Index ¶
Constants ¶
const Version = "0.4.0-beta"
Variables ¶
var ( History []string Switches []Switch DebugInfo debug.DebugInfo )
Functions ¶
func PingServer ¶
func PingServer()
Tests if the server configuration is valid and the server is reachable
func PromptLogin ¶
func PromptLogin()
The login function prompts the user to enter his password and username (if not provided via flag)
Types ¶
type LoginRequest ¶
Click to show internal directories.
Click to hide internal directories.